
# Input details on records
#path <- "E://Dropbox//Research//postdoc//Side projects//Bivalve age model//Case1_HR_results_new" # For Home PC (both)
path <- "C://Users//niels//Dropbox//Research//Manuscripts//Bivalve age model//tests//Pros20_results_new" # For laptop
setwd(path)
file_name <- "Pros20.csv" # Give file name (don't forget to add the extention, should be in CSV format)
mineral <- "calcite" # Set mineralogy of the record
t_int <- 1 # Set time interval in days
G_per <- T_per <- 365 # Set annual time period in days (default = 365)
#Texel_data <- read.csv("Texel_daily_data.csv", header = T)
# d18Ow <- read.csv("d18Osw.csv", header = FALSE)$V1 # Create d18Ow vector for one year (default = all zero)
d18Ow <- -7.65
t_maxtemp <- 182.5 # Assume taht the day of maximum temperature is halfway through the year.
MC <- 1000
agecorrection <- FALSE
plot <- TRUE
plot_export <- TRUE
export_raw <- TRUE

wrap_function(path, # Wrapping function for the entire model package
file_name, # Give file name (don't forget to add the extention, should be in CSV format)
mineral = mineral, # Set mineralogy of the record, default is calcite. Aragonite is also supported
t_int = 1, # Set time interval in days
T_per = 365, # Set annual time period in days (default = 365)
d18Ow = d18Ow, # Set d18Ow value or vector (default = constant year-round at 0 VSMOW). Alternative options are either one value (assumed constant year-round) or a vector with length T_per / t_int and interval t_int specifying d18Ow evolution through one year.
t_maxtemp = 182.5, # Define the day of the year at which temperature is heighest. Default = Assume that the day of maximum temperature is helfway through the year
MC = 1000, # Number of MC simulations to include measurement error into error analysis. Default = 1000 (if MC = 0, error on D and d18O measurements not considered)
plot = TRUE, # Should intermediate plots be given to track progress? WARNING: plotting makes the script much slower, especially for long datasets.
plot_export = TRUE, # Should a plot of the results be saved as PDF?
export_raw = FALSE # Should the results of all individual model runs be exported as CSV files?
)

# STEP 1: Import data
setwd(path)
importlist <- data_import(file_name)
dat <- importlist[[1]]
dynwindow <- importlist[[2]]
G_per <- T_per # Period of growth rate sinusoid should equal that of the temperature sinusoid (which is given)

# STEP 2: Run the model
resultlist <- run_model(dat, dynwindow, mineral, d18Ow, T_per, G_per, t_int, t_maxtemp, MC, agecorrection, plot = TRUE)
resultarray <- resultlist[[1]]
parmat <- resultlist[[2]]

# STEP 3: Align model results to cumulative timescale
print("Calculating cumulative day of the year results...")
suppressWarnings(resultarray[, , 3] <- cumulative_day(resultarray, TRUE, TRUE)) # Calculate cumulative day of the year for all model runs and replace matrix in result array

# STEP 4: Order and export results and statistics
export_results(dat, resultarray, parmat, MC, dynwindow, plot, plot_export = TRUE, export_raw = TRUE) # Export results of model
return(resultlist)