function Error = GrowthModelFit(nopt,GMP)

% SCRIPT CREATED: January 2017 (E. Judd)
% LAST CHANGED: September 2017 (E. Judd)

%CODE TO GENERATE A TEMPERATURE/ISOTOPE AND GROWTH SINUSOID IN TIME
%SPACE AND CALCULATE LEAST SQUARE ERROR BETWEEN SYNTHETIC AND MEASURED
%ISOTOPE PROFILES; THIS FUNCTION IS USED DURING THE SHUFFLED COMPLEX
%EVOLUTION ITERATION (L81 AND L 82 OF 'GrowthModelRun.m'). THIS FUNCTION IS
%ASSOCIATED WITH THE MANUSCRIPT:
    % Judd, E.J., Wilkinson, B.H., and Ivany, L.C. (2017). The life and
    % time of clams: Derivation of intra-annual growth rates from
    % high-resolution oxygen isotope profiles. Palaeogeography,
    % Palaeoclimatology, Palaeoecology.
    % https://doi.org/10.1016/j.palaeo.2017.09.034

%INPUTS:
    %nopt: number of parameters (7)
    %GMP: growth model parameters:
        %Temp. sine parameters (amplitude, phase, position)
        %Growth sine parameters (amplitude, phase, postion, skew)
        %ORDER: Tamp,Tpos,Gamp,Gpha,Gpos,Gskw,Tpha

%OUTPUTS:
    %Error: least square error between the modeled and measured oxygen isotope
    %profiles

nopt = 7;per = 365;JD = linspace(1,365,365)';
Dsamp = csvread('Dsamp.csv');
Osamp = csvread('Osamp.csv');

%Initial temp sine
Omod = ((sin((JD-GMP(7)-(per/4))*pi/per*2)*GMP(1)/2)+GMP(2))';

%Initial growth sine
for i = 1:length(JD)
    if mod(JD(i)+GMP(4)-(per/4),per) <= (per*GMP(6)/100)/2
        v = mod(JD(i)+GMP(4)-(per/4),per)/(2*(per*GMP(6)/100));
    elseif mod(JD(i)+GMP(4)-(per/4),per) <= (per*GMP(6)/100)/2+(per*(1-GMP(6)/100))
        v = (.25+(mod(JD(i)+GMP(4)-(per/4),per)-(per*GMP(6)/100)/2)/((per*(1-GMP(6)/100))*2));
    else
        v = (.75+(mod(JD(i)+GMP(4)-(per/4),per)-((per*GMP(6)/100)/2+(per*(1-GMP(6)/100))))/((per*GMP(6)/100)/2*4));
    end
    if (GMP(3)/2)*sin(2*pi*v)+GMP(5) < 0
        Rmodint(i) = 0;
    else
        Rmodint(i) = (GMP(3)/2)*sin(2*pi*v)+GMP(5);
    end
end
Rmodint = Rmodint';

%Correct length
if length(find(Rmodint==0))==365
    Rmod = Rmodint;
    Dmod = Rmodint;
else
    Dmodint = cumsum(Rmodint);
    miol = min(Dsamp); %min observed length
    maol = max(Dsamp); %max observed length
    miml = min(Dmodint);  %min modeled length
    maml = max(Dmodint);  %max modeled length
    Dmod = (Dmodint*(maol-miol)/(maml-miml))-(miml*(maol-miol)/(maml-miml))+miol;
end

%Extract Omodsamp
for i = 1:length(Dsamp)
    if length(find(Rmodint==0))==365
        Dmodsamp(i) = 0;
        Omodsamp(i) = 0;
    elseif length(find(Rmodint==0))<365 & i == 1
        m = diff(Dmod); n = find(m>0);
        Dmodsamp(i) = Dmod(n(1));
        Omodsamp(i) = Omod(n(1));
    else
        [c index] = min(abs(Dmod-Dsamp(i)));
        Dmodsamp(i) = Dmod(index);
        Omodsamp(i) = Omod(index);
    end
end
Omodsamp = Omodsamp';
Error=sum((Osamp-Omodsamp).^2);
end

