require(ggplot2)
require(gridExtra)

# Calculate accuracy of Judd et al. (2018) model
setwd("E:/Dropbox/Research/Manuscripts/Bivalve age model/tests/Performance time")
t_real <- as.data.frame(read.csv("Case1_Realtime.csv", header = TRUE)) # Import real timing data
JD_real <- ((t_real + 0.25) * 365) %% 365 # Correct for phase lag in data and convert to julian day
JD_real_cum <- (t_real + 0.25) * 365

# Loop through HR files and get stats
Dt_Judd_LR <- vector()
Dt_Judd_LR_cum <- vector()
D18O_Judd_LR <- vector()
Dt_ShellChron_LR <- vector()
Dt_ShellChron_LR_cum <- vector()
D18O_ShellChron_LR <- vector()
for(i in 12:3){
    print(i)
    # Judd et al. model
    # Load data
    setwd(paste("Case1_LR_", i, sep = "")) # Dive into simulation results
    dat <- as.data.frame(read.csv(paste("Case1_LR_", i, ".csv", sep = ""), header = TRUE))
    setwd("Judd_model") # Dive into Judd et al. model results
    Omod_Judd <- as.matrix(read.csv("Omodsamp2.csv", header = FALSE)) # Load modelled d18O result
    Omod_Judd <- as.vector(Omod_Judd[!is.na(Omod_Judd)])
    JDmod_Judd <- as.matrix(read.csv("JDmodsampshift2.csv", header = FALSE)) # Load modelled time result
    JDmod_Judd <- as.vector(JDmod_Judd[!is.na(JDmod_Judd)])

    # Create cumulative age from Judd et al. data
    YM <- which(diff(JDmod_Judd) < -1) # Find year transitions, skip "years" in the model smaller than 1/2 year
    x <- rep(0, length(JDmod_Judd))
    for(y in YM){
        x[(y + 1):length(x)] <- x[(y + 1):length(x)] + 1
    }
    JDmod_Judd_cum <- JDmod_Judd + x * 365

    # Calculate diffences between model and real data
    dt_Judd_LR <- JDmod_Judd - JD_real$t_LR[min(which(dat$YEARMARKER == 1)):(max(which(dat$YEARMARKER == 1)) - 1)] # Calculate time difference between model and data
    dt_Judd_LR[which(abs(dt_Judd_LR) > 182.5)] <- 182.5 - dt_Judd_LR[which(abs(dt_Judd_LR) > 182.5)] # If difference is more than 1/2 year, take the other half
    dt_Judd_LR_cum <- JDmod_Judd_cum - JD_real_cum$t_LR[min(which(dat$YEARMARKER == 1)):(max(which(dat$YEARMARKER == 1)) - 1)] # Calculate time difference between model and data
    dO <- Omod_Judd - dat$d18Oc[min(which(dat$YEARMARKER == 1)):(max(which(dat$YEARMARKER == 1)) - 1)] # Calculate d18Oc difference between model and data

    # Add result to matrix
    if(i < 12){
        dt_Judd_LR <- c(dt_Judd_LR, rep(NA, length(Dt_Judd_LR[, 1]) - length(dt_Judd_LR))) # Fill up difference in length with NA's before concatenation
        dt_Judd_LR_cum <- c(dt_Judd_LR_cum, rep(NA, length(Dt_Judd_LR_cum[, 1]) - length(dt_Judd_LR_cum))) # Fill up difference in length with NA's before concatenation
        dO <- c(dO, rep(NA, length(D18O_Judd_LR[, 1]) - length(dO))) # Fill up difference in length with NA's before concatenation
    }
    Dt_Judd_LR <- cbind(Dt_Judd_LR, dt_Judd_LR)
    Dt_Judd_LR_cum <- cbind(Dt_Judd_LR_cum, dt_Judd_LR_cum)
    D18O_Judd_LR <- cbind(D18O_Judd_LR, dO)
    colnames(Dt_Judd_LR)[length(Dt_Judd_LR[1, ])] <- paste("Case1_LR_", i, sep = "")
    colnames(Dt_Judd_LR_cum)[length(Dt_Judd_LR_cum[1, ])] <- paste("Case1_LR_", i, sep = "")
    colnames(D18O_Judd_LR)[length(D18O_Judd_LR[1, ])] <- paste("Case1_LR_", i, sep = "")
    setwd("E:/Dropbox/Research/Manuscripts/Bivalve age model/tests/Performance time") # return to top level

    # ShellChron
    # Load data
    setwd(paste("Case1_LR_", i, sep = "")) # Dive into simulation results
    dat <- as.data.frame(read.csv(paste("Case1_LR_", i, ".csv", sep = ""), header = TRUE))
    AMdat <- as.data.frame(read.csv("Age_model_results.csv", header = TRUE)) # Load modelled time result
    JDmod_ShellChron <- as.vector(AMdat$mean.day)
    d18Odat <- as.data.frame(read.csv("d18O_model_results.csv", header = TRUE)) # Load modelled d18O result
    Omod_ShellChron <- as.vector(d18Odat$mean.d18O_mod)

    # Calculate diffences between model and real data
    dt_ShellChron_LR <- (JDmod_ShellChron %% 365) - JD_real$t_LR[1:length(JDmod_ShellChron)] # Calculate time difference between model and data
    dt_ShellChron_LR[which(abs(dt_ShellChron_LR) > 182.5)] <- 182.5 - dt_ShellChron_LR[which(abs(dt_ShellChron_LR) > 182.5)] # If difference is more than 1/2 year, take the other half
    dt_ShellChron_LR_cum <- JDmod_ShellChron - JD_real_cum$t_LR[1:length(JDmod_ShellChron)] # Calculate time difference between model and data
    dO_ShellChron <- Omod_ShellChron - dat$d18Oc # Calculate d18Oc difference between model and data

    if(i < 12){
        dt_ShellChron_LR <- c(dt_ShellChron_LR, rep(NA, length(Dt_ShellChron_LR[, 1]) - length(dt_ShellChron_LR))) # Fill up difference in length with NA's before concatenation
        dt_ShellChron_LR_cum <- c(dt_ShellChron_LR_cum, rep(NA, length(Dt_ShellChron_LR_cum[, 1]) - length(dt_ShellChron_LR_cum))) # Fill up difference in length with NA's before concatenation
        dO_ShellChron <- c(dO_ShellChron, rep(NA, length(D18O_ShellChron_LR[, 1]) - length(dO_ShellChron))) # Fill up difference in length with NA's before concatenation
    }
    Dt_ShellChron_LR <- cbind(Dt_ShellChron_LR, dt_ShellChron_LR)
    Dt_ShellChron_LR_cum <- cbind(Dt_ShellChron_LR_cum, dt_ShellChron_LR_cum)
    D18O_ShellChron_LR <- cbind(D18O_ShellChron_LR, dO)
    colnames(Dt_ShellChron_LR)[length(Dt_ShellChron_LR[1, ])] <- paste("Case1_LR_", i, sep = "")
    colnames(Dt_ShellChron_LR_cum)[length(Dt_ShellChron_LR_cum[1, ])] <- paste("Case1_LR_", i, sep = "")
    colnames(D18O_ShellChron_LR)[length(D18O_ShellChron_LR[1, ])] <- paste("Case1_LR_", i, sep = "")
    setwd("E:/Dropbox/Research/Manuscripts/Bivalve age model/tests/Performance time") # return to top level
}

# Write away results
write.csv(D18O_Judd_LR, "D18O_Judd_et_al_LR.csv")
write.csv(Dt_Judd_LR, "Dt_Judd_et_al_LR.csv")
write.csv(Dt_Judd_LR_cum, "Dt_Judd_et_al_cumulative_LR.csv")
write.csv(D18O_ShellChron_LR, "D18O_ShellChron_LR.csv")
write.csv(Dt_ShellChron_LR, "Dt_ShellChron_LR.csv")
write.csv(Dt_ShellChron_LR_cum, "Dt_ShellChron_cumulative_LR.csv")

# Repeat for LR by replacing HR by LR

# Calculate stats
offsets <- data.frame(years = seq(12, 3, -1))
offsets$Judd_LR <- colMeans(abs(Dt_Judd_LR), na.rm = TRUE)
offsets$Judd_LR_cum <- colMeans(abs(Dt_Judd_LR_cum), na.rm = TRUE)
offsets$ShellChron_LR <- colMeans(abs(Dt_ShellChron_LR), na.rm = TRUE)
offsets$ShellChron_LR_cum <- colMeans(abs(Dt_ShellChron_LR_cum), na.rm = TRUE)
offsets$Judd_HR <- colMeans(abs(Dt_Judd_HR), na.rm = TRUE)
offsets$Judd_HR_cum <- colMeans(abs(Dt_Judd_HR_cum), na.rm = TRUE)
offsets$ShellChron_HR <- colMeans(abs(Dt_ShellChron_HR), na.rm = TRUE)
offsets$ShellChron_HR_cum <- colMeans(abs(Dt_ShellChron_HR_cum), na.rm = TRUE)

means <- data.frame(years = seq(12, 3, -1))
means$Judd_LR <- colMeans(Dt_Judd_LR, na.rm = TRUE)
means$Judd_LR_cum <- colMeans(Dt_Judd_LR_cum, na.rm = TRUE)
means$ShellChron_LR <- colMeans(Dt_ShellChron_LR, na.rm = TRUE)
means$ShellChron_LR_cum <- colMeans(Dt_ShellChron_LR_cum, na.rm = TRUE)
means$Judd_HR <- colMeans(Dt_Judd_HR, na.rm = TRUE)
means$Judd_HR_cum <- colMeans(Dt_Judd_HR_cum, na.rm = TRUE)
means$ShellChron_HR <- colMeans(Dt_ShellChron_HR, na.rm = TRUE)
means$ShellChron_HR_cum <- colMeans(Dt_ShellChron_HR_cum, na.rm = TRUE)

sds <- data.frame(years = seq(12, 3, -1))
sds$Judd_LR <- apply(abs(Dt_Judd_LR), 2, sd, na.rm = TRUE)
sds$Judd_LR_cum <- apply(abs(Dt_Judd_LR_cum), 2, sd, na.rm = TRUE)
sds$ShellChron_LR <- apply(abs(Dt_ShellChron_LR), 2, sd, na.rm = TRUE)
sds$ShellChron_LR_cum <- apply(abs(Dt_ShellChron_LR_cum), 2, sd, na.rm = TRUE)
sds$Judd_HR <- apply(abs(Dt_Judd_HR), 2, sd, na.rm = TRUE)
sds$Judd_HR_cum <- apply(abs(Dt_Judd_HR_cum), 2, sd, na.rm = TRUE)
sds$ShellChron_HR <- apply(abs(Dt_ShellChron_HR), 2, sd, na.rm = TRUE)
sds$ShellChron_HR_cum <- apply(abs(Dt_ShellChron_HR_cum), 2, sd, na.rm = TRUE)

CL95 <- function(x){return(qt(0.95, length(x[!is.na(x)])) * sd(x, na.rm = TRUE) / sqrt(length(x[!is.na(x)])))}

CLs <- data.frame(years = seq(12, 3, -1))
CLs$Judd_LR <- apply(abs(Dt_Judd_LR), 2, CL95)
CLs$Judd_LR_cum <- apply(abs(Dt_Judd_LR_cum), 2, CL95)
CLs$ShellChron_LR <- apply(abs(Dt_ShellChron_LR), 2, CL95)
CLs$ShellChron_LR_cum <- apply(abs(Dt_ShellChron_LR_cum), 2, CL95)
CLs$Judd_HR <- apply(abs(Dt_Judd_HR), 2, CL95)
CLs$Judd_HR_cum <- apply(abs(Dt_Judd_HR_cum), 2, CL95)
CLs$ShellChron_HR <- apply(abs(Dt_ShellChron_HR), 2, CL95)
CLs$ShellChron_HR_cum <- apply(abs(Dt_ShellChron_HR_cum), 2, CL95)

# Create plot
accplot <- ggplot(data = offsets, aes(years, Judd_LR_cum)) +
    geom_point(col = "deepskyblue") +
    geom_line(col = "deepskyblue") +
    geom_point(aes(years, ShellChron_LR_cum), col = "deepskyblue") +
    geom_line(aes(years, ShellChron_LR_cum), col = "deepskyblue") +
    geom_point(aes(years, Judd_HR_cum), col = "firebrick2") + 
    geom_line(aes(years, Judd_HR_cum), col = "firebrick2") +
    geom_point(aes(years, ShellChron_HR_cum), col = "firebrick2") +
    geom_line(aes(years, ShellChron_HR_cum), col = "firebrick2") +

    geom_errorbar(aes(x = years, ymin = Judd_LR_cum - CLs$Judd_LR_cum, ymax = Judd_LR_cum + CLs$Judd_LR_cum), col = "deepskyblue", width = 0.3) +
    geom_errorbar(aes(x = years, ymin = ShellChron_LR_cum - CLs$ShellChron_LR_cum, ymax = ShellChron_LR_cum + CLs$ShellChron_LR_cum), col = "deepskyblue", width = 0.3) +
    geom_errorbar(aes(x = years, ymin = Judd_HR_cum - CLs$Judd_HR_cum, ymax = Judd_HR_cum + CLs$Judd_HR_cum), col = "firebrick2", width = 0.3) +
    geom_errorbar(aes(x = years, ymin = ShellChron_HR_cum - CLs$ShellChron_HR_cum, ymax = ShellChron_HR_cum + CLs$ShellChron_HR_cum), col = "firebrick2", width = 0.3) +

    scale_y_log10("offset from actual age (d)", breaks = c(seq(1, 10, 1), seq(20, 100, 10), seq(200, 1000, 100))) +
    scale_x_continuous("Length of record (yr)", breaks = seq(3, 12, 1))

pdf("Accuracy_comparison_plot.pdf", height = 5, width = 5)
plot(accplot)
dev.off()

# Compare real model accuracy with accuracy output
# Load AMdat for the longest HR record
setwd("E:/Dropbox/Research/Manuscripts/Bivalve age model/tests/Performance time") # return to top level
setwd("Case1_HR_12") # Dive into simulation results
AMdat <- as.data.frame(read.csv("Age_model_results.csv", header = TRUE)) # Load modelled time result
Acccomp <- data.frame(D = AMdat$D, model = AMdat$CL95.day, real = abs(Dt_ShellChron_HR_cum[, 1]))
Acccomp <- Acccomp[complete.cases(Acccomp),]

acc_comp_plot <- ggplot(data = Acccomp, aes(D, model)) +
    geom_ribbon(aes(x = D, ymin = model, ymax = real), fill = "grey", alpha = 0.3) +
    geom_line(aes(D, real), col = "light blue", size = 0.5) +
    geom_line(col = "firebrick2", size = 0.5) +
    scale_x_continuous("Depth along record", breaks = seq(0, 120, 10)) +
    scale_y_continuous("Uncertainty (95% CL)", breaks = seq(0, 100, 10), limits = c(0, 100))

acc_box <- ggplot(data = stack(Acccomp[, -1])) +
    stat_boxplot(aes(x = ind, y= values), geom = "errorbar", width = 0.5) +
    geom_boxplot(aes(x = ind, y= values, fill = ind), size = 0.5, coef = 1.5, outlier.colour = "black", outlier.size = 1) +
    scale_fill_manual("", values = c("firebrick2", "light blue")) +
    scale_y_continuous("", breaks = seq(0, 100, 10), limits = c(0, 100)) +
    xlab("") +
    theme(legend.position = "none")

acc_hist <- ggplot(data = Acccomp) +
    geom_histogram(aes(real), fill = "light blue", alpha = 0.5, bins = 40) +
    geom_histogram(aes(model), fill = "firebrick2", alpha = 0.5, bins = 40) +
    scale_x_continuous("Uncertainty (95% CL)", breaks = seq(0, 100, 10), limits = c(0, 100)) +
    scale_y_continuous("Frequency", breaks = NULL)

combined_acc_comp_plots <- grid.arrange(acc_comp_plot, acc_box, ncol = 2, nrow = 1, widths = c(8, 1))

pdf("Accuracy_comparison.pdf", width = 10, height = 5)
plot(combined_acc_comp_plots)
dev.off()

pdf("Accuracy_histograms.pdf", width = 3, height = 3)
plot(acc_hist)
dev.off()
