# Performance time plots

require(ggplot2)
require(ggpubr)

# setwd("C://Users//niels//Dropbox//Research//Manuscripts//Bivalve age model//Performance time")
setwd("E://Dropbox//Research//Manuscripts//Bivalve age model//Performance time")
dat <- as.data.frame(read.csv("Timing_Case1.csv", header = TRUE))
dat <- dat[, -1]
dat$total_time <- rowSums(dat[,4:8])
dat$time_min <- dat$total_time / 60
dat$Judd_min <- dat$Judd / 60
dat$resolution <- c(rep("HR", 10), rep("LR", 10))

# Models for performance time vs. years in record
yr_LR <- dat$years[dat$resolution == "LR"]
time_LR <- dat$time_min[dat$resolution == "LR"]
Judd_LR <- dat$Judd_min[dat$resolution == "LR"]

nls_LR_yr <- nls(time_LR ~ a * exp(r * yr_LR),
    start = list(a = 10, r = 0.2)) # non-linear exponential model
lm_LR_yr <- lm(log(time_LR) ~ yr_LR) # log-linear model
lm_LRl_yr <- lm(time_LR ~ yr_LR) # linear model

nls_LR_Judd_yr <- nls(Judd_LR ~ a * exp(r * yr_LR),
    start = list(a = 10, r = 0.2)) # non-linear exponential model
lm_LR_Judd_yr <- lm(log(Judd_LR) ~ yr_LR) # log-linear model
lm_LRl_Judd_yr <- lm(Judd_LR ~ yr_LR) # linear model

yr_HR <- dat$years[dat$resolution == "HR"]
time_HR <- dat$time_min[dat$resolution == "HR"]
Judd_HR <- dat$Judd_min[dat$resolution == "HR"]

nls_HR_yr <- nls(time_HR ~ a * exp(r * yr_HR),
    start = list(a = 10, r = 0.2)) # non-linear exponential model
lm_HR_yr <- lm(log(time_HR) ~ yr_HR) # log-linear model
lm_HRl_yr <- lm(time_HR ~ yr_HR) # linear model

nls_HR_Judd_yr <- nls(Judd_HR ~ a * exp(r * yr_HR),
    start = list(a = 10, r = 0.2)) # non-linear exponential model
lm_HR_Judd_yr <- lm(log(Judd_HR) ~ yr_HR) # log-linear model
lm_HRl_Judd_yr <- lm(Judd_HR ~ yr_HR) # linear model

# Check best fitting model by naive R-squared test
RSQs_yr <- vector()
RSQs_yr <- append(RSQs_yr, cor(time_LR, exp(coef(lm_LR_yr)[1]) * exp(coef(lm_LR_yr)[2] * yr_LR)) ^ 2)
RSQs_yr <- append(RSQs_yr, cor(time_LR, coef(nls_LR_yr)[1] * exp(coef(nls_LR_yr)[2] * yr_LR)) ^ 2)
RSQs_yr <- append(RSQs_yr, cor(time_LR, coef(lm_LRl_yr)[1] + coef(lm_LRl_yr)[2] * yr_LR) ^ 2)

RSQs_yr <- append(RSQs_yr, cor(time_HR, exp(coef(lm_HR_yr)[1]) * exp(coef(lm_HR_yr)[2] * yr_HR)) ^ 2)
RSQs_yr <- append(RSQs_yr, cor(time_HR, coef(nls_HR_yr)[1] * exp(coef(nls_HR_yr)[2] * yr_HR)) ^ 2)
RSQs_yr <- append(RSQs_yr, cor(time_HR, coef(lm_HRl_yr)[1] + coef(lm_HRl_yr)[2] * yr_HR) ^ 2)

RSQs_yr <- append(RSQs_yr, cor(Judd_LR, exp(coef(lm_LR_Judd_yr)[1]) * exp(coef(lm_LR_Judd_yr)[2] * yr_LR)) ^ 2)
RSQs_yr <- append(RSQs_yr, cor(Judd_LR, coef(nls_LR_Judd_yr)[1] * exp(coef(nls_LR_Judd_yr)[2] * yr_LR)) ^ 2)
RSQs_yr <- append(RSQs_yr, cor(Judd_LR, coef(lm_LRl_Judd_yr)[1] + coef(lm_LRl_Judd_yr)[2] * yr_LR) ^ 2)

RSQs_yr <- append(RSQs_yr, cor(Judd_HR, exp(coef(lm_HR_Judd_yr)[1]) * exp(coef(lm_HR_Judd_yr)[2] * yr_HR)) ^ 2)
RSQs_yr <- append(RSQs_yr, cor(Judd_HR, coef(nls_HR_Judd_yr)[1] * exp(coef(nls_HR_Judd_yr)[2] * yr_HR)) ^ 2)
RSQs_yr <- append(RSQs_yr, cor(Judd_HR, coef(lm_HRl_Judd_yr)[1] + coef(lm_HRl_Judd_yr)[2] * yr_HR) ^ 2)
names(RSQs_yr) <- c("LR_loglinear", "LR_exponential", "LR_linear", "HR_loglinear", "HR_exponential", "HR_linear", "LR_Judd_loglinear", "LR_Judd_exponential", "LR_Judd_linear", "HR_Judd_loglinear", "HR_Judd_exponential", "HR_Judd_linear")

# Plot relative to the number of years in the record
years_plot <- ggplot2::ggplot(data = dat, ggplot2::aes(years, time_min)) +
    ggplot2::geom_point(ggplot2::aes(colour = resolution)) +
    #ggplot2::geom_line(data = dat[dat$resolution == "LR", ], ggplot2::aes(yr_LR, exp(coef(lm_LR_yr)[1]) * exp(coef(lm_LR_yr)[2] * yr_LR), col = "LR_loglinear")) +
    #ggplot2::geom_line(data = dat[dat$resolution == "LR", ], ggplot2::aes(yr_LR, coef(nls_LR_yr)[1] * exp(coef(nls_LR_yr)[2] * yr_LR), col = "LR_exponential")) +
    ggplot2::geom_line(data = dat[dat$resolution == "LR", ], ggplot2::aes(yr_LR,
        coef(lm_LRl_yr)[1] + coef(lm_LRl_yr)[2] * yr_LR,
        col = paste("Time (LR) =", round(coef(lm_LRl_yr)[1], 2), "+", round(coef(lm_LRl_yr)[2], 2), "* year", sep=" ")
        )) +
    #ggplot2::geom_line(data = dat[dat$resolution == "HR", ], ggplot2::aes(yr_HR, exp(coef(lm_HR_yr)[1]) * exp(coef(lm_HR_yr)[2] * yr_HR), col = "HR_loglinear")) +
    #ggplot2::geom_line(data = dat[dat$resolution == "HR", ], ggplot2::aes(yr_HR, coef(nls_HR_yr)[1] * exp(coef(nls_HR_yr)[2] * yr_HR), col = "HR_exponential")) +
    ggplot2::geom_line(data = dat[dat$resolution == "HR", ], ggplot2::aes(yr_HR,
        coef(lm_HRl_yr)[1] + coef(lm_HRl_yr)[2] * yr_HR,
        col = paste("Time (HR) =", round(coef(lm_HRl_yr)[1], 2), "+", round(coef(lm_HRl_yr)[2], 2), "* year", sep=" ")
        )) +

    ggplot2::geom_point(ggplot2::aes(years, Judd_min, colour = resolution)) +
    #ggplot2::geom_line(data = dat[dat$resolution == "LR", ], ggplot2::aes(yr_LR, exp(coef(lm_LR_Judd_yr)[1]) * exp(coef(lm_LR_Judd_yr)[2] * yr_LR), col = "LR_loglinear")) +
    #ggplot2::geom_line(data = dat[dat$resolution == "LR", ], ggplot2::aes(yr_LR, coef(nls_LR_Judd_yr)[1] * exp(coef(nls_LR_Judd_yr)[2] * yr_LR), col = "LR_exponential")) +
    ggplot2::geom_line(data = dat[dat$resolution == "LR", ], ggplot2::aes(yr_LR,
        coef(lm_LRl_Judd_yr)[1] + coef(lm_LRl_Judd_yr)[2] * yr_LR,
        col = paste("Time (LR_Judd18) =", round(coef(lm_LRl_Judd_yr)[1], 2), "+", round(coef(lm_LRl_Judd_yr)[2], 2), "* year", sep=" ")
        )) +
    #ggplot2::geom_line(data = dat[dat$resolution == "HR", ], ggplot2::aes(yr_HR, exp(coef(lm_HR_Judd_yr)[1]) * exp(coef(lm_HR_Judd_yr)[2] * yr_HR), col = "HR_loglinear")) +
    #ggplot2::geom_line(data = dat[dat$resolution == "HR", ], ggplot2::aes(yr_HR, coef(nls_HR_Judd_yr)[1] * exp(coef(nls_HR_Judd_yr)[2] * yr_HR), col = "HR_exponential")) +
    ggplot2::geom_line(data = dat[dat$resolution == "HR", ], ggplot2::aes(yr_HR,
        coef(lm_HRl_Judd_yr)[1] + coef(lm_HRl_Judd_yr)[2] * yr_HR,
        col = paste("Time (HR_Judd18) =", round(coef(lm_HRl_Judd_yr)[1], 2), "+", round(coef(lm_HRl_Judd_yr)[2], 2), "* year", sep=" ")
        )) +

    ggplot2::ggtitle("Total time to run the model vs record length in years") +
    ggplot2::xlab("Record length (in years)") +
    ggplot2::ylab("Total time taken to run the full model (in minutes)") +
    ggplot2::scale_x_continuous(breaks = round(seq(min(dat$years), max(dat$years), by = 1), 1)) +
    ggplot2::scale_y_continuous(breaks = round(seq(0, max(dat$time_min) + 60, by = 60), 60))

"pdf("Performance_time_years.pdf", width = 5, height = 5)
print(years_plot)
dev.off()"

# Exponential model for performance time vs. windows in record
window_LR <- dat$windows[dat$resolution == "LR"]
time_LR <- dat$time_min[dat$resolution == "LR"]
nls_LR_window <- nls(time_LR ~ a * exp(r * window_LR),
    start = list(a = 10, r = 0.01)) # non-linear exponential model
lm_LR_window <- lm(log(time_LR) ~ window_LR) # log-linear model
lm_LRl_window <- lm(time_LR ~ window_LR) # linear model

window_HR <- dat$windows[dat$resolution == "HR"]
time_HR <- dat$time_min[dat$resolution == "HR"]
nls_HR_window <- nls(time_HR ~ a * exp(r * window_HR),
    start = list(a = 10, r = 0.01)) # non-linear exponential model
lm_HR_window <- lm(log(time_HR) ~ window_HR) # log-linear model
lm_HRl_window <- lm(time_HR ~ window_HR) # linear model

# Check best fitting model by naive R-squared test
RSQs_window <- vector()
RSQs_window <- append(RSQs_window, cor(time_LR, exp(coef(lm_LR_window)[1]) * exp(coef(lm_LR_window)[2] * window_LR)) ^ 2)
RSQs_window <- append(RSQs_window, cor(time_LR, coef(nls_LR_window)[1] * exp(coef(nls_LR_window)[2] * window_LR)) ^ 2)
RSQs_window <- append(RSQs_window, cor(time_LR, coef(lm_LRl_window)[1] + coef(lm_LRl_window)[2] * window_LR) ^ 2)
RSQs_window <- append(RSQs_window, cor(time_HR, exp(coef(lm_HR_window)[1]) * exp(coef(lm_HR_window)[2] * window_HR)) ^ 2)
RSQs_window <- append(RSQs_window, cor(time_HR, coef(nls_HR_window)[1] * exp(coef(nls_HR_window)[2] * window_HR)) ^ 2)
RSQs_window <- append(RSQs_window, cor(time_HR, coef(lm_HRl_window)[1] + coef(lm_HRl_window)[2] * window_HR) ^ 2)
names(RSQs_window) <- c("LR_loglinear", "LR_exponential", "LR_linear", "HR_loglinear", "HR_exponential", "HR_linear")

# Plot relative to the number of sample windows in the record
windows_plot <- ggplot2::ggplot(data = dat, ggplot2::aes(windows, time_min)) +
    ggplot2::geom_point(ggplot2::aes(colour = resolution)) +
    #ggplot2::geom_line(data = dat[dat$resolution == "LR", ], ggplot2::aes(window_LR, exp(coef(lm_LR_window)[1]) * exp(coef(lm_LR_window)[2] * window_LR), col = "LR_loglinear")) +
    #ggplot2::geom_line(data = dat[dat$resolution == "LR", ], ggplot2::aes(window_LR, coef(nls_LR_window)[1] * exp(coef(nls_LR_window)[2] * window_LR), col = "LR_exponential")) +
    ggplot2::geom_line(data = dat[dat$resolution == "LR", ], ggplot2::aes(window_LR,
        coef(lm_LRl_window)[1] + coef(lm_LRl_window)[2] * window_LR,
        col = paste("Time (LR) =", round(coef(lm_LRl_window)[1], 2), "+", round(coef(lm_LRl_window)[2], 2), "* window", sep=" ")
    )) +
    #ggplot2::geom_line(data = dat[dat$resolution == "HR", ], ggplot2::aes(window_HR, exp(coef(lm_HR_window)[1]) * exp(coef(lm_HR_window)[2] * window_HR), col = "HR_loglinear")) +
    #ggplot2::geom_line(data = dat[dat$resolution == "HR", ], ggplot2::aes(window_HR, coef(nls_HR_window)[1] * exp(coef(nls_HR_window)[2] * window_HR), col = "HR_exponential")) +
    ggplot2::geom_line(data = dat[dat$resolution == "HR", ], ggplot2::aes(window_HR,
        coef(lm_HRl_window)[1] + coef(lm_HRl_window)[2] * window_HR,
        col = paste("Time (HR) =", round(coef(lm_HRl_window)[1], 2), "+", round(coef(lm_HRl_window)[2], 2), "* window", sep=" ")
    )) +
    ggplot2::ggtitle("Total time to run the model vs record length in windows") +
    ggplot2::xlab("Record length (in windows)") +
    ggplot2::ylab("Total time taken to run the full model (in minutes)") +
    ggplot2::scale_x_continuous(breaks = round(seq(min(dat$windows), max(dat$windows) + 50, by = 50), 50)) +
    ggplot2::scale_y_continuous(breaks = round(seq(0, max(dat$time_min) + 60, by = 60), 60))

# Exponential model for performance time vs. samples in record
sample_LR <- dat$samples[dat$resolution == "LR"]
time_LR <- dat$time_min[dat$resolution == "LR"]
nls_LR_sample <- nls(time_LR ~ a * exp(r * sample_LR),
    start = list(a = 10, r = 0.01)) # non-linear exponential model
lm_LR_sample <- lm(log(time_LR) ~ sample_LR) # log-linear model
lm_LRl_sample <- lm(time_LR ~ sample_LR) # linear model

sample_HR <- dat$samples[dat$resolution == "HR"]
time_HR <- dat$time_min[dat$resolution == "HR"]
nls_HR_sample <- nls(time_HR ~ a * exp(r * sample_HR),
    start = list(a = 10, r = 0.01)) # non-linear exponential model
lm_HR_sample <- lm(log(time_HR) ~ sample_HR) # log-linear model
lm_HRl_sample <- lm(time_HR ~ sample_HR) # linear model

# Check best fitting model by naive R-squared test
RSQs_sample <- vector()
RSQs_sample <- append(RSQs_sample, cor(time_LR, exp(coef(lm_LR_sample)[1]) * exp(coef(lm_LR_sample)[2] * sample_LR)) ^ 2)
RSQs_sample <- append(RSQs_sample, cor(time_LR, coef(nls_LR_sample)[1] * exp(coef(nls_LR_sample)[2] * sample_LR)) ^ 2)
RSQs_sample <- append(RSQs_sample, cor(time_LR, coef(lm_LRl_sample)[1] + coef(lm_LRl_sample)[2] * sample_LR) ^ 2)
RSQs_sample <- append(RSQs_sample, cor(time_HR, exp(coef(lm_HR_sample)[1]) * exp(coef(lm_HR_sample)[2] * sample_HR)) ^ 2)
RSQs_sample <- append(RSQs_sample, cor(time_HR, coef(nls_HR_sample)[1] * exp(coef(nls_HR_sample)[2] * sample_HR)) ^ 2)
RSQs_sample <- append(RSQs_sample, cor(time_HR, coef(lm_HRl_sample)[1] + coef(lm_HRl_sample)[2] * sample_HR) ^ 2)
names(RSQs_sample) <- c("LR_loglinear", "LR_exponential", "LR_linear", "HR_loglinear", "HR_exponential", "HR_linear")

# Plot relative to the number of samples in the record
samples_plot <- ggplot2::ggplot(data = dat, ggplot2::aes(samples, time_min)) +
    ggplot2::geom_point(ggplot2::aes(colour = resolution)) +
    #ggplot2::geom_line(data = dat[dat$resolution == "LR", ], ggplot2::aes(sample_LR, exp(coef(lm_LR_sample)[1]) * exp(coef(lm_LR_sample)[2] * sample_LR), col = "LR_loglinear")) +
    #ggplot2::geom_line(data = dat[dat$resolution == "LR", ], ggplot2::aes(sample_LR, coef(nls_LR_sample)[1] * exp(coef(nls_LR_sample)[2] * sample_LR), col = "LR_exponential")) +
    ggplot2::geom_line(data = dat[dat$resolution == "LR", ], ggplot2::aes(sample_LR,
        coef(lm_LRl_sample)[1] + coef(lm_LRl_sample)[2] * sample_LR,
        col = paste("Time (LR) =", round(coef(lm_LRl_sample)[1], 2), "+", round(coef(lm_LRl_sample)[2], 2), "* sample", sep=" ")
    )) +
    #ggplot2::geom_line(data = dat[dat$resolution == "HR", ], ggplot2::aes(sample_HR, exp(coef(lm_HR_sample)[1]) * exp(coef(lm_HR_sample)[2] * sample_HR), col = "HR_loglinear")) +
    #ggplot2::geom_line(data = dat[dat$resolution == "HR", ], ggplot2::aes(sample_HR, coef(nls_HR_sample)[1] * exp(coef(nls_HR_sample)[2] * sample_HR), col = "HR_exponential")) +
    ggplot2::geom_line(data = dat[dat$resolution == "HR", ], ggplot2::aes(sample_HR,
        coef(lm_HRl_sample)[1] + coef(lm_HRl_sample)[2] * sample_HR,
        col = paste("Time (HR) =", round(coef(lm_HRl_sample)[1], 2), "+", round(coef(lm_HRl_sample)[2], 2), "* sample", sep=" ")
    )) +
    ggplot2::ggtitle("Total time to run the model vs record length in samples") +
    ggplot2::xlab("Record length (in samples)") +
    ggplot2::ylab("Total time taken to run the full model (in minutes)") +
    ggplot2::scale_x_continuous(breaks = round(seq(min(dat$samples), max(dat$samples) + 50, by = 50), 50)) +
    ggplot2::scale_y_continuous(breaks = round(seq(0, max(dat$time_min) + 60, by = 60), 60))

Combined_plots <- ggpubr::ggarrange( # Combine plots
    years_plot,
    windows_plot,
    samples_plot,
    labels = c("A", "B", "C"),
    ncol = 3,
    nrow = 1)

# Export plot results (optional)
setwd("E:/Dropbox/Research/Manuscripts/Bivalve age model/Figures")
pdf("Performance time plots.pdf", width = 20, height = 5)
print(Combined_plots)
dev.off()